@@ -17,8 +17,6 @@ use namespace::autoclean;
 with 'Dist::Zilla::Role::Plugin';
 with 'Dist::Zilla::Role::TextTemplater';
 
-our $Hook;
-
 has text => (
     is          => 'rw',
     isa         => 'ArrayRef[Str]',
@@ -34,11 +32,7 @@ around mvp_multivalue_args => sub {
 sub BUILD {
     my ( $self ) = @_;
     my $string = join( "\n", @{ $self->text } );
-    if ( $Hook ) {
-        $string = $Hook->( $self, $string );
-    } else {
-        $string = $self->fill_in_string( $string );
-    };
+    $string = $self->fill_in_string( $string );
     $self->text( [ split( "\n", $string ) ] );
 };
 
