@@ -28,8 +28,7 @@ use autodie ':all';
 use namespace::autoclean;
 
 use Test::Routine;
-
-with 'Test::Dist::Zilla::Build';
+with 'PluginTester';
 
 use Test::More;
 use Test::Deep qw{ cmp_deeply };
@@ -40,11 +39,6 @@ has text => (
     default     => sub { [] },
 );
 
-has delimiters => (
-    is          => 'ro',
-    isa         => 'Str',
-);
-
 has package => (
     is          => 'ro',
     isa         => 'Str',
@@ -56,60 +50,44 @@ has prepend => (
     default     => sub { [] },
 );
 
-sub _build_plugins {
+has exp_text => (
+    is          => 'ro',
+    isa         => 'ArrayRef[Str]',
+    default     => sub { [] },
+);
+
+sub _build_plugin { '=TextTemplaterTestPlugin' };
+
+sub _build_ini_body {
     my ( $self ) = @_;
     return [
         'GatherDir',
-        [ '=TextTemplaterTestPlugin', {
+        [ $self->plugin, {
             'text' => $self->text,
-            $self->delimiters   ? ( delimiters => $self->delimiters ) : (),
-            $self->package      ? ( package    => $self->package    ) : (),
-            @{ $self->prepend } ? ( prepend    => $self->prepend    ) : (),
+            $self->package      ? ( package => $self->package ) : (),
+            @{ $self->prepend } ? ( prepend => $self->prepend ) : (),
         } ]
     ];
 };
 
-sub _build_message_filter {
-    return sub {
-        map(
-            { ( my $r = $_ ) =~ s{^\[[^\[\]]*\] }{}; $r; }
-            grep( { $_ =~ m{^\[=TextTemplaterTestPlugin\] } } @_ )
-        );
-    };
-};
-
-has hook => (
-    is          => 'ro',
-    isa         => 'CodeRef',
-);
-
-around build => sub {
-    my ( $orig, $self, @args ) = @_;
-    local $TextTemplaterTestPlugin::Hook = $self->hook if $self->hook;
-    return $self->$orig( @args );
-};
-
-test 'Text' => sub {
-
+before anno => sub {
     my ( $self ) = @_;
-    my $expected = $self->expected;
-
-    if ( $self->exception ) {
-        plan skip_all => 'exception occurred';
+    my $in = $self->text;
+    diag( "Template:\n" . join( "\n", @$in ) . "\n(end)" );
+    if ( not $self->has_exception ) {
+        my $out = $self->tzil->plugin_named( $self->plugin )->text;
+        diag( "Output text:\n" . join( "\n", @$out ) . "\n(end)" );
     };
-    if ( not exists( $expected->{ text } ) ) {
-        plan skip_all => 'no expected text';
+};
+
+sub check {
+    my ( $self ) = @_;
+    if ( defined( $self->exp_exception ) ) {
+        skip 'build must fail — no need to check text', 1;
+    } else {
+        my $plugin = $self->tzil->plugin_named( $self->plugin );
+        cmp_deeply( $plugin->text, $self->exp_text, 'text' );
     };
-
-    plan tests => 1;
-
-    my $plugin = $self->tzil->plugin_named( '=TextTemplaterTestPlugin' );
-    $self->_anno_text( 'Template', @{ $self->text } );
-    $self->_anno_text( 'Output', @{ $plugin->text } );
-    cmp_deeply( $plugin->text, $expected->{ text }, 'text' );
-
-    done_testing;
-
 };
 
 1;
